@@ -14,8 +14,8 @@ def parse() -> Tuple[str, str, XlsParserFormat]:
     parser.add_argument("--output", "-o", type=str,
                         help="Путь к директории с выводом",
                         required=False, default=None)
-    parser.add_argument("--format", type=XlsParserFormat,
+    parser.add_argument("--format", type=int,
                         help="Формат данных",
-                        required=False, default=XlsParserFormat.first_format)
+                        required=False, default=XlsParserFormat.first_format.value)
     options = parser.parse_args()
-    return options.folder, options.output, options.format
+    return options.folder, options.output, XlsParserFormat(options.format)
